;; Generated package description from flymake.el  -*- no-byte-compile: t -*-
(define-package "flymake" "1.4.0.0.20250420.222033" "A universal on-the-fly syntax checker" '((emacs "26.1") (eldoc "1.14.0") (project "0.7.1")) :commit "23583bb3a140883edda4ca8958f0447da75e0eea" :url "https://elpa.gnu.org/packages/flymake.html" :authors '(("Pavel Kobyakov" . "pk_at_work@yahoo.com")) :maintainer '("Spencer Baugh" . "sbaugh@janestreet.com") :keywords '("c" "languages" "tools"))
